Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2064)

Unified Diff: content/browser/ssl/ssl_manager.h

Issue 2467773002: Notify SSLManager when all password fields on a page are gone (Closed)
Patch Set: tweak SSLManager comment Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/ssl/ssl_manager.h
diff --git a/content/browser/ssl/ssl_manager.h b/content/browser/ssl/ssl_manager.h
index 40a86a348eaaf1cc90e9fe1d13dc5fff8ddb1f6d..f135133efdf15a389317983bb941f8f07e18d182 100644
--- a/content/browser/ssl/ssl_manager.h
+++ b/content/browser/ssl/ssl_manager.h
@@ -84,6 +84,7 @@ class CONTENT_EXPORT SSLManager {
void DidDisplayMixedContent();
void DidDisplayContentWithCertErrors();
void DidShowPasswordInputOnHttp();
+ void DidHideAllPasswordInputsOnHttp();
void DidShowCreditCardInputOnHttp();
void DidRunMixedContent(const GURL& security_origin);
void DidRunContentWithCertErrors(const GURL& security_origin);
@@ -112,16 +113,19 @@ class CONTENT_EXPORT SSLManager {
int options_mask);
// Updates the NavigationEntry's |content_status| flags according to
// state in |ssl_host_state_delegate| and
// |additional_content_status_flags|, a bitmask of
// SSLStatus::ContentStatusFlags. (Pass 0 to set no additional content
// status flags.) This will notify the WebContents of an SSL state
// change if a change was actually made.
void UpdateEntry(NavigationEntryImpl* entry,
- int additional_content_status_flags);
+ int add_content_status_flags,
+ int remove_content_status_flags);
// Helper function for UpdateEntry().
- void UpdateLastCommittedEntry(int additional_content_status_flags);
+ void UpdateLastCommittedEntry(int add_content_status_flags,
+ int remove_content_status_flags);
// Notifies the WebContents that the SSL state changed.
void NotifyDidChangeVisibleSSLState();
« no previous file with comments | « components/password_manager/content/browser/visible_password_observer.cc ('k') | content/browser/ssl/ssl_manager.cc » ('j') | no next file with comments »
@@ -112,16 +113,19 @@ class CONTENT_EXPORT SSLManager {
int options_mask);
// Updates the NavigationEntry's |content_status| flags according to
- // state in |ssl_host_state_delegate| and
- // |additional_content_status_flags|, a bitmask of
- // SSLStatus::ContentStatusFlags. (Pass 0 to set no additional content
- // status flags.) This will notify the WebContents of an SSL state
+ // state in |ssl_host_state_delegate|. |add_content_status_flags| and
+ // |remove_content_status_flags| are bitmasks of
+ // SSLStatus::ContentStatusFlags that will be added or removed from
+ // the |content_status| field. (Pass 0 to add/remove no content status
+ // flags.) This method will notify the WebContents of an SSL state
// change if a change was actually made.
void UpdateEntry(NavigationEntryImpl* entry,

Powered by Google App Engine
This is Rietveld 408576698